summaryrefslogtreecommitdiffstats
path: root/lib/kformula/kformulacommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/kformulacommand.h')
-rw-r--r--lib/kformula/kformulacommand.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kformula/kformulacommand.h b/lib/kformula/kformulacommand.h
index bc1703be..09001040 100644
--- a/lib/kformula/kformulacommand.h
+++ b/lib/kformula/kformulacommand.h
@@ -495,13 +495,13 @@ public:
void addTextElement( TextElement* element ) { list.append(element); }
/**
* Collects all parent elements those children are to be changend.
*/
void addElement( BasicElement* element ) { elementList.append( element ); }
protected:
- TQPtrList<TextElement>& childrenList() { return list; }
+ TQPtrList<TextElement>& tqchildrenList() { return list; }
void collectChildren();
@@ -520,7 +520,7 @@ private:
/**
* Changes the char style of a number of elements an their children.
*/
class CharStyleCommand : public FontCommand {
public:
@@ -539,7 +539,7 @@ private:
/**
* Changes the char family of a number of elements an their children.
*/
class CharFamilyCommand : public FontCommand {
public:
@@ -495,13 +495,13 @@ public:
void addTextElement( TextElement* element ) { list.append(element); }
/**
- * Collects all parent elements those children are to be changend.
+ * Collects all parent elements those tqchildren are to be changend.
*/
void addElement( BasicElement* element ) { elementList.append( element ); }
@@ -520,7 +520,7 @@ private:
/**
- * Changes the char style of a number of elements an their children.
+ * Changes the char style of a number of elements an their tqchildren.
*/
class CharStyleCommand : public FontCommand {
@@ -539,7 +539,7 @@ private:
/**
- * Changes the char family of a number of elements an their children.
+ * Changes the char family of a number of elements an their tqchildren.
*/
class CharFamilyCommand : public FontCommand {